allinkl

package module
v0.0.0-...-f5c51dc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: MIT Imports: 3 Imported by: 0

README

all-inkl module for Caddy

This package contains a DNS provider module for Caddy. It can be used to manage DNS records with all-inkl.

Caddy module name

dns.providers.allinkl

Config examples

To use this module for the ACME DNS challenge, configure the ACME issuer in your Caddy JSON like so:

{
	"module": "acme",
	"challenges": {
		"dns": {
			"provider": {
				"name": "allinkl",
				"kas_username": "YOUR_KAS_USERNAME",
				"kas_password": "YOUR_KAS_PASSWORD"
			}
		}
	}
}

or with the Caddyfile:

# globally
{
	acme_dns allinkl {
		kas_username {env.KAS_USERNAME}
		kas_password {env.KAS_PASSWORD}
	}
}
# one site
tls {
  dns allinkl {
    kas_username {env.KAS_USERNAME}
    kas_password {env.KAS_PASSWORD}
  }
}

Docker example

  1. Install docker and docker-compose, then run:
apt install docker.io docker-compose
  1. Build the docker image using the provided Dockerfile and build script:
cd test-docker
chmod +x build/build.sh
./build/build.sh
  1. Change the name of the .env.example to .env file to include your all-inkl KAS credentials:

  2. Edit the Caddyfile in the test-docker/caddy directory to configure your desired domains and settings.

  3. Start the Caddy server with docker-compose:

docker-compose up -d

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Provider

type Provider struct{ *allinkl.Provider }

Provider lets Caddy read and manipulate DNS records hosted by this DNS provider.

func (Provider) CaddyModule

func (Provider) CaddyModule() caddy.ModuleInfo

CaddyModule returns the Caddy module information.

func (*Provider) Provision

func (p *Provider) Provision(ctx caddy.Context) error

Provision sets up the module. Implements caddy.Provisioner.

func (*Provider) UnmarshalCaddyfile

func (p *Provider) UnmarshalCaddyfile(d *caddyfile.Dispenser) error

UnmarshalCaddyfile sets up the DNS provider from Caddyfile tokens. Syntax:

allinkl [<username> <password>] {
    kas_username <username>
    kas_password <password>
}

Jump to